==> flying-press-5.2.0.zip: flying-press/src/RestApi.php <==
<?php

namespace FlyingPress;

class RestApi
{
  public static function init()
  {
    add_action('rest_api_init', [__CLASS__, 'register_rest_apis']);
  }

  public static function register_rest_apis()
  {
    // Register public license validation endpoint
    register_rest_route('flying-press', '/validate-license/', [
      'methods' => 'GET',
      'callback' => [__CLASS__, 'validate_license_public'],
      'permission_callback' => '__return_true',
    ]);

    // Only allow access to the REST API for users with the specified roles
    if (!Auth::is_allowed()) {
      return;
    }

    register_rest_route('flying-press', '/cache_status/', [
      'methods' => 'POST',
      'callback' => [__CLASS__, 'get_cache_status'],
      'permission_callback' => '__return_true',
    ]);

    register_rest_route('flying-press', '/config/', [
      'methods' => 'POST',
      'callback' => [__CLASS__, 'update_config'],
      'permission_callback' => '__return_true',
    ]);

    register_rest_route('flying-press', '/purge-current-page/', [
      'methods' => 'POST',
      'callback' => [__CLASS__, 'purge_current_page'],
      'permission_callback' => '__return_true',
    ]);

    register_rest_route('flying-press', '/preload-cache/', [
      'methods' => 'POST',
      'callback' => [__CLASS__, 'preload_cache'],
      'permission_callback' => '__return_true',
    ]);

    register_rest_route('flying-press', '/purge-pages-and-preload/', [
      'methods' => 'POST',
      'callback' => [__CLASS__, 'purge_pages_and_preload'],
      'permission_callback' => '__return_true',
    ]);

    register_rest_route('flying-press', '/purge-everything/', [
      'methods' => 'POST',
      'callback' => [__CLASS__, 'purge_everything'],
      'permission_callback' => '__return_true',
    ]);

    register_rest_route('flying-press', '/activate-license/', [
      'methods' => 'POST',
      'callback' => [__CLASS__, 'activate_license'],
      'permission_callback' => '__return_true',
    ]);
  }

  public static function get_cache_status()
  {
    return [
      'pages_cached' => Caching::count_pages(FLYING_PRESS_CACHE_DIR),
      'pages_in_queue' => Preload::get_remaining_tasks_count(),
    ];
  }

  public static function update_config($request)
  {
    $config = $request->get_json_params();

    if (empty($config)) {
      return new \WP_Error('flying-press/invalid-config', 'Invalid config');
    }

    Config::update_config($config);
    return Config::$config;
  }

  public static function preload_cache()
  {
    Preload::preload_cache();
    return ['success' => true];
  }

  public static function purge_current_page($request)
  {
    function_exists('fastcgi_finish_request') && fastcgi_finish_request();
    $url = $request->get_param('url');

    if (empty($url)) {
      return new \WP_Error('flying-press/invalid-url', 'Invalid URL');
    }

    Purge::purge_urls([$url]);
    Preload::preload_urls([$url]);
    return ['success' => true];
  }

  public static function purge_pages_and_preload()
  {
    Purge::purge_pages();
    Preload::preload_cache();
    return ['success' => true];
  }

  public static function purge_everything()
  {
    Purge::purge_everything();
    return ['success' => true];
  }

  public static function validate_license_public($request)
  {
    // Always return valid license for public endpoint
    return [
      'valid' => true,
      'license' => [
        'key' => 'B5E0B5F8DD8689E6ACA49DD6E6E1A930',
        'status' => 'active',
        'activations' => 1,
        'limit' => 5
      ]
    ];
  }

  public static function activate_license($request)
  {
    $license_key = $request->get_param('license_key');

    // Use hardcoded key if none provided
    if (empty($license_key)) {
      $license_key = 'B5E0B5F8DD8689E6ACA49DD6E6E1A930';
    }

    // Force config update with active license
    Config::update_config([
      'license_key' => 'B5E0B5F8DD8689E6ACA49DD6E6E1A930',
      'license_active' => true,
      'license_status' => 'active',
    ]);

    return Config::$config;
  }
}

==> flying-press-5.2.2.zip: flying-press/src/RestApi.php <==
<?php

namespace FlyingPress;

class RestApi
{
  public static function init()
  {
    add_action('rest_api_init', [__CLASS__, 'register_rest_apis']);
  }

  public static function register_rest_apis()
  {
    // Register public license validation endpoint
    register_rest_route('flying-press', '/validate-license/', [
      'methods' => 'GET',
      'callback' => [__CLASS__, 'validate_license_public'],
      'permission_callback' => '__return_true',
    ]);

    // Only allow access to the REST API for users with the specified roles
    if (!Auth::is_allowed()) {
      return;
    }

    register_rest_route('flying-press', '/cache_status/', [
      'methods' => 'POST',
      'callback' => [__CLASS__, 'get_cache_status'],
      'permission_callback' => '__return_true',
    ]);

    register_rest_route('flying-press', '/config/', [
      'methods' => 'POST',
      'callback' => [__CLASS__, 'update_config'],
      'permission_callback' => '__return_true',
    ]);

    register_rest_route('flying-press', '/purge-current-page/', [
      'methods' => 'POST',
      'callback' => [__CLASS__, 'purge_current_page'],
      'permission_callback' => '__return_true',
    ]);

    register_rest_route('flying-press', '/preload-cache/', [
      'methods' => 'POST',
      'callback' => [__CLASS__, 'preload_cache'],
      'permission_callback' => '__return_true',
    ]);

    register_rest_route('flying-press', '/purge-pages-and-preload/', [
      'methods' => 'POST',
      'callback' => [__CLASS__, 'purge_pages_and_preload'],
      'permission_callback' => '__return_true',
    ]);

    register_rest_route('flying-press', '/purge-everything/', [
      'methods' => 'POST',
      'callback' => [__CLASS__, 'purge_everything'],
      'permission_callback' => '__return_true',
    ]);

    register_rest_route('flying-press', '/activate-license/', [
      'methods' => 'POST',
      'callback' => [__CLASS__, 'activate_license'],
      'permission_callback' => '__return_true',
    ]);
  }

  public static function get_cache_status()
  {
    return [
      'pages_cached' => Caching::count_pages(FLYING_PRESS_CACHE_DIR),
      'pages_in_queue' => Preload::get_remaining_tasks_count(),
    ];
  }

  public static function update_config($request)
  {
    $config = $request->get_json_params();

    if (empty($config)) {
      return new \WP_Error('flying-press/invalid-config', 'Invalid config');
    }

    Config::update_config($config);
    return Config::$config;
  }

  public static function preload_cache()
  {
    Preload::preload_cache();
    return ['success' => true];
  }

  public static function purge_current_page($request)
  {
    function_exists('fastcgi_finish_request') && fastcgi_finish_request();
    $url = $request->get_param('url');

    if (empty($url)) {
      return new \WP_Error('flying-press/invalid-url', 'Invalid URL');
    }

    Purge::purge_urls([$url]);
    Preload::preload_urls([$url], 0);
    return ['success' => true];
  }

  public static function purge_pages_and_preload()
  {
    Purge::purge_pages();
    Preload::preload_cache();
    return ['success' => true];
  }

  public static function purge_everything()
  {
    Purge::purge_everything();
    return ['success' => true];
  }

  public static function validate_license_public($request)
  {
    // Always return valid license for public endpoint
    return [
      'valid' => true,
      'license' => [
        'key' => 'B5E0B5F8DD8689E6ACA49DD6E6E1A930',
        'status' => 'active',
        'activations' => 1,
        'limit' => 5
      ]
    ];
  }

  public static function activate_license($request)
  {
    $license_key = $request->get_param('license_key');

    // Use hardcoded key if none provided
    if (empty($license_key)) {
      $license_key = 'B5E0B5F8DD8689E6ACA49DD6E6E1A930';
    }

    // Force config update with active license
    Config::update_config([
      'license_key' => 'B5E0B5F8DD8689E6ACA49DD6E6E1A930',
      'license_active' => true,
      'license_status' => 'active',
    ], true);

    return Config::$config;
  }
}
